//
// "$Id: VncGroup.cxx,v 1.3 2004/09/23 08:37:35 dooglio2 Exp $"
//

/* Copyright (c) 2003 R. Douglas Barbieri <doug@dooglio.net>
 *
 * This file is part of VncSelector.
 *
 * VncSelector  is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * VncSelector  is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with VncSelector ; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include <stdio.h>
#include <stdlib.h>

#include "VncGroup.h"
#include "vncselector.xpm"

VncGroup::VncGroup(int X, int Y, int W, int H, const char *l)
  : Fl_Group(X,Y,W,H,l)
{
#ifdef DEBUG
  printf( "VncGroup::VncGroup()\n" );
#endif
	m_defaultIcon.reset( new Fl_Pixmap( vncselector_xpm ) );
	m_sizedIcon.reset( m_defaultIcon->copy( w(), h() ) );
}

VncGroup::~VncGroup()
{
#ifdef DEBUG
  printf( "VncGroup::~VncGroup()\n" );
#endif
}


void	VncGroup::ReplaceThumbnail( XImage* image )
{
#ifdef DEBUG
	printf( "ReplaceThumbnail()\n" );
#endif

	m_thumbnail_image.reset( new VncImage );
	m_thumbnail_image->Image( image );

#ifdef DEBUG
	printf( "done with ReplaceThumbnail()\n" );
#endif

	redraw();	
}


void VncGroup::ClearThumbnail()
{
#ifdef DEBUG
  printf( "VncGroup::ClearThumbnail()\n" );
#endif
  ReplaceThumbnail( NULL );
}


void VncGroup::Redraw()
{
#ifdef DEBUG
  printf( "VncGroup::Redraw()\n" );
#endif
	if( m_thumbnail_image.get() && m_thumbnail_image->Image() )
	{	
		window()->make_current();
		m_thumbnail_image->PutImage(
				fl_display,
				fl_window,
				VncRect( x(), y(), w(), h() )
		);
	}
	else
	{
		if( !((m_sizedIcon->w() == w()) && ((m_sizedIcon->h() == h()))) )
		{
			m_sizedIcon.reset( m_defaultIcon->copy( w(), h() ) );
		}
		m_sizedIcon->draw( x(), y(), w(), h(), 0, 0 );
	}
}


void VncGroup::draw()
{
#ifdef DEBUG
  printf( "VncGroup::draw()\n" );
#endif
  Fl_Group::draw();
  Redraw();
}


/* $Log: VncGroup.cxx,v $
/* Revision 1.3  2004/09/23 08:37:35  dooglio2
/* Added VncSelector logo so it shows up when there are no sessions loaded.
/*
/* Revision 1.2  2004/09/20 06:37:38  dooglio2
/* Adding code to allow thumbnail of logo when no image selected.
/*
/* Revision 1.1.1.1  2004/09/19 20:11:39  dooglio2
/* Adding for the first time.
/*
/* Revision 1.1.1.1  2004/09/15 09:43:43  doug
/* Adding version 2 with autoconf support.
/*
/* Revision 1.1.1.1  2004/09/15 09:06:23  doug
/* This is VncSelector 2, with configure support.
/*
/* Revision 1.6  2004/01/07 00:38:24  doug
/* Moved image manipulation code into a new class, VncImage.
/*
/* Revision 1.5  2004/01/06 19:27:58  doug
/* Thumbnail support is more stable (but still needs a redesign).
/* Retabbed all code to "expandtab."
/* VncThread is now back to being a template (seems to work better).
/*
/* Revision 1.4  2004/01/06 08:16:54  doug
/* Work in progress. Thumbnailing works, but is flakey, particularly with regards
/* to "Kill Session."
/*
/* Revision 1.3  2004/01/04 08:27:51  doug
/* Work in progress...
/*
/* Revision 1.2  2004/01/04 02:22:39  doug
/* Fixed deadlocking. If sessions exist, list is selected.
/*
 *
 */
