/*******************************************************************************
 * VncOptions.cxx
 *
 * For now, a "poor man's" configuration file. Eventually want to get this
 * stuff from a true config file.
 *
 * $Id: VncOptions.cxx,v 1.1.1.1 2004/09/19 20:11:40 dooglio2 Exp $
 *
 ********************************************************************************/

/* Copyright (c) 2003 R. Douglas Barbieri
 *
 * This file is part of VncSelector.
 *
 * VncSelector  is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * VncSelector  is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with VncSelector ; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "VncOptions.h"
#include "common.h"

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>


# define VNCVIEWER            "viewer"
# define VNCVIEWER_ENCODINGS  "viewer_encodings"
# define VNCSERVER            "server"

# define VNCVIEWER_DEFAULT    "/usr/bin/vncviewer"
# define VNCENCODINGS_DEFAULT "copyrect tight hextile zlib corre rre raw"
# define VNCSERVER_DEFAULT    "/usr/bin/vncserver"


/* VncOptions::GetOption()
 *
 * Searches through the map and gets a named option value
 */
const bool VncOptions::GetOption( const string& name, string& value )
{
  if( m_options.find( name ) == m_options.end() )
  {
    return false;
  }
  value = m_options[name];
  return true;
}


/* VncOptions::CreateDefaultOptions()
 *
 * Called first time the program is run and creates a default
 * config file.
 */
const bool VncOptions::CreateDefaultOptions()
{
  FILE* optfile = fopen( m_optionFilePath.c_str(), "w" );
  if( optfile == NULL )
  {
    return false;
  }

  fprintf( optfile, "%s=%s\n", VNCVIEWER,           VNCVIEWER_DEFAULT    );
  fprintf( optfile, "%s=%s\n", VNCVIEWER_ENCODINGS, VNCENCODINGS_DEFAULT );
  fprintf( optfile, "%s=%s\n", VNCSERVER,           VNCSERVER_DEFAULT    );

  fclose( optfile );

  return true;
}


/* VncOptions::LoadOptions()
 *
 * Attempts to load the VncSelector configuration file. If not found,
 * it will call CreateDefaultOptions() above to initialize with
 * default values.
 *
 * The m_options map is loaded with name,value pairs.
 */
const bool VncOptions::LoadOptions()
{
  FILE* optfile = fopen( m_optionFilePath.c_str(), "r" );
  if( optfile == NULL )
  {
    fprintf(stderr,
        "Options file non-existant--creating first time\n" );

    if( !CreateDefaultOptions() )
    {
      fprintf(stderr,
          "Cannot create options file: %s!\n",
          m_optionFilePath.c_str());
      return false;
    }

    optfile = fopen( m_optionFilePath.c_str(), "r" );
    if( optfile == NULL )
    {
      fprintf(stderr,
          "Fatal error reading configuration file: %s!\n",
          m_optionFilePath.c_str() );
      return false;
    }
  }

  char buf[1024+1];
  while( fgets( buf, 1024, optfile ) != NULL )
  {
    std::string line( VncCommon::Strip( buf ) );

    if( line[0] == '#' )
    {
      // Ignore comments
      continue;
    }

    char*  c_name   = new char[line.length()+1];
    char*  c_value  = new char[line.length()+1];

    if( sscanf( buf, "%[^=]=%[^\n]\n", c_name, c_value ) == 2 )
    {
      string name ( VncCommon::Strip( c_name  ) );
      string value( VncCommon::Strip( c_value ) );

#ifdef DEBUG
      printf( "name: \"%s\", value: \"%s\"\n", name.c_str(), value.c_str() );
#endif

			// TODO: Need a way to validate options--right now you can put
			// any old name,value pair in the config file and this object will
			// suck it up like it's okay.
			//
      m_options[name] = value;
    }

    delete c_name;
    delete c_value;
  }

  fclose( optfile );

  return true;
}

/*
 * $Log: VncOptions.cxx,v $
 * Revision 1.1.1.1  2004/09/19 20:11:40  dooglio2
 * Adding for the first time.
 *
 * Revision 1.1.1.1  2004/09/15 09:43:44  doug
 * Adding version 2 with autoconf support.
 *
 * Revision 1.1.1.1  2004/09/15 09:06:23  doug
 * This is VncSelector 2, with configure support.
 *
 * Revision 1.2  2004/02/07 21:40:45  doug
 * Can make under Debian stable.
 *
 * Revision 1.1  2004/02/07 21:16:03  doug
 * Added config file support.
 *
 *
 */
