/*******************************************************************************
 * VncSelector.h
 *
 * Provides the definition for the VncSelector class.
 *
 * $Id: VncSelector.h,v 1.2 2004/09/23 08:37:35 dooglio2 Exp $
 *
 ********************************************************************************/

/* Copyright (c) 2003 R. Douglas Barbieri
 *
 * This file is part of VncSelector.
 *
 * VncSelector  is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * VncSelector  is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with VncSelector ; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __VNC_SELECTOR_H__
#define __VNC_SELECTOR_H__

#include <string>
#include <map>

// This is an auto-generated header produced by FLUID
// Please see the Makefile for more information.
//
#include "VncSelectorUI.h"
#include "VncWaitDlgUI.h"
#include "VncThread.h"


// class VncSelector
//
// This class is follows the Singleton pattern. This insures there
// is only one instance ever, since the default, copy constructor
// and default assignment operator are private.
//
// VncSelector manages a list of running VNC sessions, and allows
// the user to start, terminate and connect to instances.
//
// It inherits from the VncSelectorUI class, which wraps the GUI
// components.
//
class VncSelector :
            public VncSelectorUI,
            public VncThreadClient
{
public:
    virtual ~VncSelector();

    static VncSelector* Instance();

    void show( int argc, char **argv );
    void Redraw();

    // Called by add remote server
    //
    const bool AddRemoteDisplay( const char* display_name );

    // Called by VncThread
    //
    virtual void UserRunThread();

private:
    // Environment
    //
    typedef std::map<std::string,std::string> EnvMap;
    EnvMap  m_environment;

    // User VNC directory (usally ~/.vnc).
    //
    std::string m_vncdir;
    std::string m_viewer;
    std::string m_viewer_encodings;
    std::string m_server;

    // Array of VNC pid files
    //
    struct	VncPid
    {
        pid_t		m_pid;
        std::string	m_display;
        std::string	m_fileName;
    };

    typedef	std::vector<VncPid>	VncPidVector;
    VncPidVector						m_vncPids;

    // Instance of class, only one.
    //
    static VncSelector*     m_instance;

    // Wait dialog instance
    //
    VncWaitDlg*             m_waitDlg;

    // Thread members
    //
    char **                 m_argv;
    char **                 m_env_array;

    bool                    m_wait;
    bool                    m_triggerThread;
    int											m_fork_status;

    VncMutex                m_mutex;
    VncThread               m_thread;

    // Private constructors and default assignment
    // operators--this follows the Singleton pattern
    //
    VncSelector();
    VncSelector( const VncSelector& );
    void operator =( const VncSelector& );

    // Private operations
    //
    void	ReadVncDir();

    void  PopulateEnvMap();
    void  UpdateEnvArray();

    // called by GUI events
    //
    void ListClick();
    void ConnectToSelection();
    void KillSelection();
    void CreateSession();

    void LoadSessionList();
    void ShowWaitDlg( const bool show = true );

    void AddRemoteServer();

    // Graphics stuff
    //
    void GenerateThumbnail();

    // thread related functions
    //
    void	ClearArgArray();
    void  TriggerThread( char **argv );
    void  DoFork();
};

#endif // __VNC_SELECTOR_H__
